import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import React, { lazy as reactLazy, Suspense } from 'react';
import { lazy as loadableLazy } from '@loadable/component';
import { loadSpinner } from './LoadSpinner';
/**
 * 组件导入函数,支持自定义加载动画
 * Create a loadable component "Suspense" ready.
 * @param {Function} func 返回动态引入的函数, 如 ()=>import('./a/b/c')
 * @param {Object} options {spinner:spinner, // loading动画组件, 默认为loadSpinner, 其他参数参考LoadSpinner组件}
 * @returns {Component}
 */

export var lazy = function lazy(func, options) {
  if (options === void 0) {
    options = {};
  }

  var _options = options,
      spinner = _options.spinner,
      restOptions = _objectWithoutPropertiesLoose(_options, ["spinner"]);

  var LazyComponent = /*#__PURE__*/reactLazy(func);
  return function LazyComponentFunc(props) {
    return /*#__PURE__*/React.createElement(Suspense, {
      fallback: loadSpinner(spinner, restOptions)
    }, /*#__PURE__*/React.createElement(LazyComponent, props));
  };
};
/**
 * 组件导入函数,支持自定义加载动画
 * @param {Function} func 返回动态引入的函数, 如 ()=>import('./a/b/c')
 * @param {Object} options {spinner:spinner, // loading动画组件, 默认为loadSpinner, 其他参数参考LoadSpinner组件}
 * @returns {Component}
 */

export var lazyX = function lazyX(func, options) {
  if (options === void 0) {
    options = {};
  }

  var _options2 = options,
      spinner = _options2.spinner,
      restOptions = _objectWithoutPropertiesLoose(_options2, ["spinner"]);

  var LazyXComponent = loadableLazy(func);
  return function LazyXComponentFunc(props) {
    return /*#__PURE__*/React.createElement(Suspense, {
      fallback: loadSpinner(spinner, restOptions)
    }, /*#__PURE__*/React.createElement(LazyXComponent, props));
  };
};
/**
 * lib动态导入函数
 * @param {Function} func 返回动态引入的函数, 如 ()=>import('abc')
 */

export var lazyLib = loadableLazy.lib;