import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
// https://github.com/gregberge/loadable-components
import ttLoadable from '@loadable/component';
import pMinDelay from 'p-min-delay';
import { timeout } from 'promise-timeout';
import { loadSpinner } from './LoadSpinner';
/**
 * 组件导入函数,支持自定义加载动画
 * @param {Function} func 返回动态引入的函数, 如 ()=>import('./a/b/c')
 * @param {Object} options {spinner:spinner, // loading动画组件, 默认为loadSpinner, 其他参数参考LoadSpinner组件}
 * @returns {Component}
 */

export var loadable = function loadable(func, options) {
  if (options === void 0) {
    options = {};
  }

  var _options = options,
      spinner = _options.spinner,
      restOptions = _objectWithoutPropertiesLoose(_options, ["spinner"]);

  return ttLoadable(func, _extends({
    fallback: loadSpinner(spinner, restOptions)
  }, restOptions));
};
/**
 * 组件导入函数,支持延时加载
 * @param {Promise} promise 动态引入的返回值, 如 import('./a/b/c')
 * @param {Object} options {spinner:spinner, // loading动画组件, 默认为loadSpinner, delay:200, // 延迟时间, 默认200ms, 其他参数参考LoadSpinner组件}
 * @returns {Component}
 */

export var loadableDelay = function loadableDelay(promise, options) {
  if (options === void 0) {
    options = {};
  }

  var _options2 = options,
      spinner = _options2.spinner,
      _options2$delay = _options2.delay,
      delay = _options2$delay === void 0 ? 200 : _options2$delay,
      restOptions = _objectWithoutPropertiesLoose(_options2, ["spinner", "delay"]);

  return ttLoadable(function () {
    return pMinDelay(promise, delay);
  }, _extends({
    fallback: loadSpinner(spinner, restOptions)
  }, restOptions));
};
/**
 * 组件导入函数,支持加载超时
 * @param {Promise} promise 动态引入的返回值, 如 import('./a/b/c')
 * @param {Object} options {spinner:spinner, // loading动画组件, 默认为loadSpinner, time:200, // 过期时间, 默认5000ms, 其他参数参考LoadSpinner组件}
 * @returns {Component}
 */

export var loadableTimeout = function loadableTimeout(promise, options) {
  if (options === void 0) {
    options = {
      time: 5000
    };
  }

  var _options3 = options,
      spinner = _options3.spinner,
      _options3$time = _options3.time,
      time = _options3$time === void 0 ? 5000 : _options3$time,
      restOptions = _objectWithoutPropertiesLoose(_options3, ["spinner", "time"]);

  return ttLoadable(function () {
    return timeout(promise, time);
  }, _extends({
    fallback: loadSpinner(spinner, restOptions)
  }, restOptions));
};
/**
 * lib动态导入函数
 * @param {Function} func 返回动态引入的函数, 如 ()=>import('abc')
 */

export var loadableLib = ttLoadable.lib;